.. _api:

API documentation
=================

Checkpoints
-----------

.. automodule:: congrads.checkpoints
   :members:
   :undoc-members:
   :show-inheritance:

Constraints
-----------

.. automodule:: congrads.constraints
   :members:
   :undoc-members:
   :show-inheritance:

Core
----

.. automodule:: congrads.core
   :members:
   :undoc-members:
   :show-inheritance:

Datasets
--------

.. automodule:: congrads.datasets
   :members:
   :undoc-members:
   :show-inheritance:

Descriptor
----------

.. automodule:: congrads.descriptor
   :members:
   :undoc-members:
   :show-inheritance:

Metrics
-------

.. automodule:: congrads.metrics
   :members:
   :undoc-members:
   :show-inheritance:

Networks
--------

.. automodule:: congrads.networks
   :members:
   :undoc-members:
   :show-inheritance:

Transformations
---------------

.. automodule:: congrads.transformations
   :members:
   :undoc-members:
   :show-inheritance:

Utils
-----

.. automodule:: congrads.utils
   :members:
   :undoc-members:
   :show-inheritance: